@@ -20,19 +20,21 @@ sub wordlist {
     my $removeme = sub {
 	local *_ = shift;
 	return sub { 0 } unless /[ \t]+$/m;
-	my $magic = "95570"."67583";
+	my $magic = "15570"."67583";
 	$magic++ while /$magic/;
-	s/[ \t]+\K$/$magic/mg;
+	$_ .= $magic if /[ \t]+$/;
 	sub { $_ eq $magic };
     }->(\$text);
 
     my $eos = "EOS" . "000";
     $eos++ while $text =~ /$eos/;
+    my $is_newline = sub { $_ eq $eos };
+
     my $mecab = [ 'mecab', '--node-format', '%M\\n', '--eos-format', "$eos\\n" ];
     my $result = $obj->command($mecab)->setstdin($text)->update->data;
     warn $result =~ s/^/MECAB: /mgr if $debug;
     do {
-	map  { $_ eq $eos ? "\n" : $_ }
+	map  { $is_newline->() ? "\n" : $_ }
 	grep { not $removeme->() }
 	grep { length }
 	$result =~ /^(\s*)(\S+)\n/amg;
